complete -c elf2nucleus -s t -l timeout -d 'Timeout in seconds for micronucleus device discovery' -r
complete -c elf2nucleus -l completions -d 'Generate shell completions' -r -f -a "{bash	'',elvish	'',fish	'',powershell	'',zsh	''}"
complete -c elf2nucleus -s v -l verbose -d 'Increase logging output (can be used multiple times)'
complete -c elf2nucleus -s h -l help -d 'Print help'
